protoconv

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package protoconv translates a small subset of protobuf (.proto) schemas into Cap'n Proto (.capnp) source, so capwrap users can author services in familiar proto syntax. Each unary `rpc M(Req) returns (Resp)` is flattened: the fields of Req/Resp become the Cap'n Proto method's params/results.

Supported: proto3, a service with unary rpc methods, and messages made of scalar/string/bytes fields. Streaming, repeated, map, oneof, enums and nested message fields are not supported and cause the affected method to be skipped.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToCapnp

func ToCapnp(src string) (capnp string, skipped []string, err error)

ToCapnp parses proto source and returns equivalent Cap'n Proto source. Skipped lists methods that could not be translated (with the reason).

Types

This section is empty.

Jump to